==> maleo_metadata-0.0.13-py3-none-any.whl: maleo_metadata/clients/services/blood_type.py <==
from fastapi import status
from maleo_foundation.utils.exceptions import BaseExceptions
from maleo_metadata.enums.general import MaleoMetadataGeneralEnums
from maleo_metadata.clients.utils.logger import MaleoMetadataClientLoggerManager
from maleo_metadata.clients.http.controllers.blood_type import MaleoMetadataBloodTypeHTTPClientController
from maleo_metadata.models.transfers.parameters.general.blood_type import MaleoMetadataBloodTypeGeneralParametersTransfers
from maleo_metadata.models.transfers.parameters.client.blood_type import MaleoMetadataBloodTypeClientParametersTransfers
from maleo_metadata.models.transfers.results.general.blood_type import MaleoMetadataBloodTypeGeneralResultsTransfers
from maleo_metadata.types.results.general.blood_type import MaleoMetadataBloodTypeGeneralResultsTypes

class MaleoMetadataBloodTypeClientService:
    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving blood types",
        logger=MaleoMetadataClientLoggerManager.get(),
        fail_result_class=MaleoMetadataBloodTypeGeneralResultsTransfers.Fail
    )
    async def get_blood_types(
        parameters:MaleoMetadataBloodTypeClientParametersTransfers.GetMultiple,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataBloodTypeGeneralResultsTypes.GetMultiple:
        """Retrieve blood types from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve blood types using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataBloodTypeHTTPClientController.get_blood_types(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
        else:
            if controller_result.content["data"] is None:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
            else:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.MultipleData.model_validate(controller_result.content)

    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving blood type",
        logger=MaleoMetadataClientLoggerManager.get(),
        fail_result_class=MaleoMetadataBloodTypeGeneralResultsTransfers.Fail
    )
    async def get_blood_type(
        parameters:MaleoMetadataBloodTypeGeneralParametersTransfers.GetSingle,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataBloodTypeGeneralResultsTypes.GetSingle:
        """Retrieve blood type from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve blood type using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataBloodTypeHTTPClientController.get_blood_type(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            if controller_result.status_code != status.HTTP_404_NOT_FOUND:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
            else:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
        else:
            return MaleoMetadataBloodTypeGeneralResultsTransfers.SingleData.model_validate(controller_result.content)

==> maleo_metadata-0.0.14-py3-none-any.whl: maleo_metadata/clients/services/blood_type.py <==
from fastapi import status
from maleo_foundation.utils.exceptions import BaseExceptions
from maleo_metadata.enums.general import MaleoMetadataGeneralEnums
from maleo_metadata.utils.logger import MaleoMetadataLoggerManager
from maleo_metadata.clients.http.controllers.blood_type import MaleoMetadataBloodTypeHTTPClientController
from maleo_metadata.models.transfers.parameters.general.blood_type import MaleoMetadataBloodTypeGeneralParametersTransfers
from maleo_metadata.models.transfers.parameters.client.blood_type import MaleoMetadataBloodTypeClientParametersTransfers
from maleo_metadata.models.transfers.results.general.blood_type import MaleoMetadataBloodTypeGeneralResultsTransfers
from maleo_metadata.types.results.general.blood_type import MaleoMetadataBloodTypeGeneralResultsTypes

class MaleoMetadataBloodTypeClientService:
    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving blood types",
        logger=MaleoMetadataLoggerManager.get(),
        fail_result_class=MaleoMetadataBloodTypeGeneralResultsTransfers.Fail
    )
    async def get_blood_types(
        parameters:MaleoMetadataBloodTypeClientParametersTransfers.GetMultiple,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataBloodTypeGeneralResultsTypes.GetMultiple:
        """Retrieve blood types from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve blood types using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataBloodTypeHTTPClientController.get_blood_types(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
        else:
            if controller_result.content["data"] is None:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
            else:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.MultipleData.model_validate(controller_result.content)

    @staticmethod
    @BaseExceptions.service_exception_handler(
        operation="retrieving blood type",
        logger=MaleoMetadataLoggerManager.get(),
        fail_result_class=MaleoMetadataBloodTypeGeneralResultsTransfers.Fail
    )
    async def get_blood_type(
        parameters:MaleoMetadataBloodTypeGeneralParametersTransfers.GetSingle,
        controller_type:MaleoMetadataGeneralEnums.ClientControllerType = MaleoMetadataGeneralEnums.ClientControllerType.HTTP
    ) -> MaleoMetadataBloodTypeGeneralResultsTypes.GetSingle:
        """Retrieve blood type from MaleoMetadata"""
        #* Validate chosen controller type
        if not isinstance(controller_type, MaleoMetadataGeneralEnums.ClientControllerType):
            message = "Invalid controller type"
            description = "The provided controller type did not exists"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Retrieve blood type using chosen controller
        if controller_type == MaleoMetadataGeneralEnums.ClientControllerType.HTTP:
            controller_result = await MaleoMetadataBloodTypeHTTPClientController.get_blood_type(parameters=parameters)
        else:
            message = "Invalid controller type"
            description = "The provided controller type has not been implemented"
            return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail(message=message, description=description)
        #* Return proper response
        if not controller_result.success:
            if controller_result.status_code != status.HTTP_404_NOT_FOUND:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.Fail.model_validate(controller_result.content)
            else:
                return MaleoMetadataBloodTypeGeneralResultsTransfers.NoData.model_validate(controller_result.content)
        else:
            return MaleoMetadataBloodTypeGeneralResultsTransfers.SingleData.model_validate(controller_result.content)
